@@ -142,6 +142,12 @@ sub _num_to_res {
 	return $num;
 }
 
+has 'retry_mem_percent' => (
+	isa => 'Int',
+	is  => 'ro',
+	default => 99
+);
+
 sub _vmem_usage {
 	my $self    = shift;
 	my $run     = shift;
@@ -166,7 +172,7 @@ sub _vmem_usage {
 	my $cmd  = "tail -1 $stderr";
 	my $last = `$cmd`;
 	if ($last =~ /Out of memory\!/
-			|| $pct >= 99
+			|| $pct >= $self->retry_mem_percent
 			|| $self->memory_too_small->($stats, $stderr)) {
 		return $self->_can_retry_from_vmem(
 			$pct > 100
